from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Microsoft.UI.Composition
import win32more.Microsoft.UI.Xaml
import win32more.Microsoft.UI.Xaml.Media
import win32more.Microsoft.UI.Xaml.Shapes
import win32more.Windows.Win32.System.WinRT
class Ellipse(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Shapes.Shape
    default_interface: win32more.Microsoft.UI.Xaml.Shapes.IEllipse
    _classid_ = 'Microsoft.UI.Xaml.Shapes.Ellipse'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Shapes.Ellipse.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Shapes.Ellipse: ...
class IEllipse(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IEllipse'
    _iid_ = Guid('{805c39aa-fa8a-5e0b-9847-4ab81b42a3df}')
class ILine(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.ILine'
    _iid_ = Guid('{507b3858-af7e-559b-a87e-4cc6a5d8ba96}')
    @winrt_commethod(6)
    def get_X1(self) -> Double: ...
    @winrt_commethod(7)
    def put_X1(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_Y1(self) -> Double: ...
    @winrt_commethod(9)
    def put_Y1(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_X2(self) -> Double: ...
    @winrt_commethod(11)
    def put_X2(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_Y2(self) -> Double: ...
    @winrt_commethod(13)
    def put_Y2(self, value: Double) -> Void: ...
    X1 = property(get_X1, put_X1)
    X2 = property(get_X2, put_X2)
    Y1 = property(get_Y1, put_Y1)
    Y2 = property(get_Y2, put_Y2)
class ILineStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.ILineStatics'
    _iid_ = Guid('{a425bf93-f1f3-5dcb-997e-b6a26f7ae8c0}')
    @winrt_commethod(6)
    def get_X1Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_Y1Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_X2Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_Y2Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    X1Property = property(get_X1Property, None)
    X2Property = property(get_X2Property, None)
    Y1Property = property(get_Y1Property, None)
    Y2Property = property(get_Y2Property, None)
class IPath(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IPath'
    _iid_ = Guid('{757d1cd8-0ec0-55c5-b400-66657e493e78}')
    @winrt_commethod(6)
    def get_Data(self) -> win32more.Microsoft.UI.Xaml.Media.Geometry: ...
    @winrt_commethod(7)
    def put_Data(self, value: win32more.Microsoft.UI.Xaml.Media.Geometry) -> Void: ...
    Data = property(get_Data, put_Data)
class IPathFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IPathFactory'
    _iid_ = Guid('{5e82e4c9-7502-5b1f-b940-c3346a71362a}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Microsoft.UI.Xaml.Shapes.Path: ...
class IPathStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IPathStatics'
    _iid_ = Guid('{2146d36f-721c-5b54-af7d-60f3adc4fbca}')
    @winrt_commethod(6)
    def get_DataProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DataProperty = property(get_DataProperty, None)
class IPolygon(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IPolygon'
    _iid_ = Guid('{fa126347-d1d4-54dd-b1a4-c35019397944}')
    @winrt_commethod(6)
    def get_FillRule(self) -> win32more.Microsoft.UI.Xaml.Media.FillRule: ...
    @winrt_commethod(7)
    def put_FillRule(self, value: win32more.Microsoft.UI.Xaml.Media.FillRule) -> Void: ...
    @winrt_commethod(8)
    def get_Points(self) -> win32more.Microsoft.UI.Xaml.Media.PointCollection: ...
    @winrt_commethod(9)
    def put_Points(self, value: win32more.Microsoft.UI.Xaml.Media.PointCollection) -> Void: ...
    FillRule = property(get_FillRule, put_FillRule)
    Points = property(get_Points, put_Points)
class IPolygonStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IPolygonStatics'
    _iid_ = Guid('{85ddbada-9e37-5971-a9aa-dce31f9cf67a}')
    @winrt_commethod(6)
    def get_FillRuleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_PointsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FillRuleProperty = property(get_FillRuleProperty, None)
    PointsProperty = property(get_PointsProperty, None)
class IPolyline(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IPolyline'
    _iid_ = Guid('{c7f0bec6-184c-5d96-8102-04dd211e100c}')
    @winrt_commethod(6)
    def get_FillRule(self) -> win32more.Microsoft.UI.Xaml.Media.FillRule: ...
    @winrt_commethod(7)
    def put_FillRule(self, value: win32more.Microsoft.UI.Xaml.Media.FillRule) -> Void: ...
    @winrt_commethod(8)
    def get_Points(self) -> win32more.Microsoft.UI.Xaml.Media.PointCollection: ...
    @winrt_commethod(9)
    def put_Points(self, value: win32more.Microsoft.UI.Xaml.Media.PointCollection) -> Void: ...
    FillRule = property(get_FillRule, put_FillRule)
    Points = property(get_Points, put_Points)
class IPolylineStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IPolylineStatics'
    _iid_ = Guid('{48840fe7-d735-5080-9c6d-2862665cdda0}')
    @winrt_commethod(6)
    def get_FillRuleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_PointsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FillRuleProperty = property(get_FillRuleProperty, None)
    PointsProperty = property(get_PointsProperty, None)
class IRectangle(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IRectangle'
    _iid_ = Guid('{bf7d30b9-152c-556e-9f10-d0b7eba4e52f}')
    @winrt_commethod(6)
    def get_RadiusX(self) -> Double: ...
    @winrt_commethod(7)
    def put_RadiusX(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_RadiusY(self) -> Double: ...
    @winrt_commethod(9)
    def put_RadiusY(self, value: Double) -> Void: ...
    RadiusX = property(get_RadiusX, put_RadiusX)
    RadiusY = property(get_RadiusY, put_RadiusY)
class IRectangleStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IRectangleStatics'
    _iid_ = Guid('{3cc3cc79-c332-5ad0-8743-1f1b1e670a86}')
    @winrt_commethod(6)
    def get_RadiusXProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_RadiusYProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    RadiusXProperty = property(get_RadiusXProperty, None)
    RadiusYProperty = property(get_RadiusYProperty, None)
class IShape(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IShape'
    _iid_ = Guid('{9941aad3-6af2-5ba2-9085-8506d5f2485e}')
    @winrt_commethod(6)
    def get_Fill(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(7)
    def put_Fill(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(8)
    def get_Stroke(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(9)
    def put_Stroke(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(10)
    def get_StrokeMiterLimit(self) -> Double: ...
    @winrt_commethod(11)
    def put_StrokeMiterLimit(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_StrokeThickness(self) -> Double: ...
    @winrt_commethod(13)
    def put_StrokeThickness(self, value: Double) -> Void: ...
    @winrt_commethod(14)
    def get_StrokeStartLineCap(self) -> win32more.Microsoft.UI.Xaml.Media.PenLineCap: ...
    @winrt_commethod(15)
    def put_StrokeStartLineCap(self, value: win32more.Microsoft.UI.Xaml.Media.PenLineCap) -> Void: ...
    @winrt_commethod(16)
    def get_StrokeEndLineCap(self) -> win32more.Microsoft.UI.Xaml.Media.PenLineCap: ...
    @winrt_commethod(17)
    def put_StrokeEndLineCap(self, value: win32more.Microsoft.UI.Xaml.Media.PenLineCap) -> Void: ...
    @winrt_commethod(18)
    def get_StrokeLineJoin(self) -> win32more.Microsoft.UI.Xaml.Media.PenLineJoin: ...
    @winrt_commethod(19)
    def put_StrokeLineJoin(self, value: win32more.Microsoft.UI.Xaml.Media.PenLineJoin) -> Void: ...
    @winrt_commethod(20)
    def get_StrokeDashOffset(self) -> Double: ...
    @winrt_commethod(21)
    def put_StrokeDashOffset(self, value: Double) -> Void: ...
    @winrt_commethod(22)
    def get_StrokeDashCap(self) -> win32more.Microsoft.UI.Xaml.Media.PenLineCap: ...
    @winrt_commethod(23)
    def put_StrokeDashCap(self, value: win32more.Microsoft.UI.Xaml.Media.PenLineCap) -> Void: ...
    @winrt_commethod(24)
    def get_StrokeDashArray(self) -> win32more.Microsoft.UI.Xaml.Media.DoubleCollection: ...
    @winrt_commethod(25)
    def put_StrokeDashArray(self, value: win32more.Microsoft.UI.Xaml.Media.DoubleCollection) -> Void: ...
    @winrt_commethod(26)
    def get_Stretch(self) -> win32more.Microsoft.UI.Xaml.Media.Stretch: ...
    @winrt_commethod(27)
    def put_Stretch(self, value: win32more.Microsoft.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_commethod(28)
    def get_GeometryTransform(self) -> win32more.Microsoft.UI.Xaml.Media.Transform: ...
    @winrt_commethod(29)
    def GetAlphaMask(self) -> win32more.Microsoft.UI.Composition.CompositionBrush: ...
    Fill = property(get_Fill, put_Fill)
    GeometryTransform = property(get_GeometryTransform, None)
    Stretch = property(get_Stretch, put_Stretch)
    Stroke = property(get_Stroke, put_Stroke)
    StrokeDashArray = property(get_StrokeDashArray, put_StrokeDashArray)
    StrokeDashCap = property(get_StrokeDashCap, put_StrokeDashCap)
    StrokeDashOffset = property(get_StrokeDashOffset, put_StrokeDashOffset)
    StrokeEndLineCap = property(get_StrokeEndLineCap, put_StrokeEndLineCap)
    StrokeLineJoin = property(get_StrokeLineJoin, put_StrokeLineJoin)
    StrokeMiterLimit = property(get_StrokeMiterLimit, put_StrokeMiterLimit)
    StrokeStartLineCap = property(get_StrokeStartLineCap, put_StrokeStartLineCap)
    StrokeThickness = property(get_StrokeThickness, put_StrokeThickness)
class IShapeFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IShapeFactory'
    _iid_ = Guid('{4fecafaf-8265-5252-ba5c-f43639f974a5}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Microsoft.UI.Xaml.Shapes.Shape: ...
class IShapeStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Shapes.IShapeStatics'
    _iid_ = Guid('{ea407c43-8a09-587a-958a-4dd17d217ce1}')
    @winrt_commethod(6)
    def get_FillProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_StrokeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_StrokeMiterLimitProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_StrokeThicknessProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_StrokeStartLineCapProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_StrokeEndLineCapProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_StrokeLineJoinProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_StrokeDashOffsetProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_StrokeDashCapProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_StrokeDashArrayProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_StretchProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FillProperty = property(get_FillProperty, None)
    StretchProperty = property(get_StretchProperty, None)
    StrokeDashArrayProperty = property(get_StrokeDashArrayProperty, None)
    StrokeDashCapProperty = property(get_StrokeDashCapProperty, None)
    StrokeDashOffsetProperty = property(get_StrokeDashOffsetProperty, None)
    StrokeEndLineCapProperty = property(get_StrokeEndLineCapProperty, None)
    StrokeLineJoinProperty = property(get_StrokeLineJoinProperty, None)
    StrokeMiterLimitProperty = property(get_StrokeMiterLimitProperty, None)
    StrokeProperty = property(get_StrokeProperty, None)
    StrokeStartLineCapProperty = property(get_StrokeStartLineCapProperty, None)
    StrokeThicknessProperty = property(get_StrokeThicknessProperty, None)
class _Line_Meta_(ComPtr.__class__):
    pass
class Line(ComPtr, metaclass=_Line_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Shapes.Shape
    default_interface: win32more.Microsoft.UI.Xaml.Shapes.ILine
    _classid_ = 'Microsoft.UI.Xaml.Shapes.Line'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Shapes.Line.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Shapes.Line: ...
    @winrt_mixinmethod
    def get_X1(self: win32more.Microsoft.UI.Xaml.Shapes.ILine) -> Double: ...
    @winrt_mixinmethod
    def put_X1(self: win32more.Microsoft.UI.Xaml.Shapes.ILine, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_Y1(self: win32more.Microsoft.UI.Xaml.Shapes.ILine) -> Double: ...
    @winrt_mixinmethod
    def put_Y1(self: win32more.Microsoft.UI.Xaml.Shapes.ILine, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_X2(self: win32more.Microsoft.UI.Xaml.Shapes.ILine) -> Double: ...
    @winrt_mixinmethod
    def put_X2(self: win32more.Microsoft.UI.Xaml.Shapes.ILine, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_Y2(self: win32more.Microsoft.UI.Xaml.Shapes.ILine) -> Double: ...
    @winrt_mixinmethod
    def put_Y2(self: win32more.Microsoft.UI.Xaml.Shapes.ILine, value: Double) -> Void: ...
    @winrt_classmethod
    def get_X1Property(cls: win32more.Microsoft.UI.Xaml.Shapes.ILineStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_Y1Property(cls: win32more.Microsoft.UI.Xaml.Shapes.ILineStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_X2Property(cls: win32more.Microsoft.UI.Xaml.Shapes.ILineStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_Y2Property(cls: win32more.Microsoft.UI.Xaml.Shapes.ILineStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    X1 = property(get_X1, put_X1)
    X2 = property(get_X2, put_X2)
    Y1 = property(get_Y1, put_Y1)
    Y2 = property(get_Y2, put_Y2)
    _Line_Meta_.X1Property = property(get_X1Property, None)
    _Line_Meta_.X2Property = property(get_X2Property, None)
    _Line_Meta_.Y1Property = property(get_Y1Property, None)
    _Line_Meta_.Y2Property = property(get_Y2Property, None)
class _Path_Meta_(ComPtr.__class__):
    pass
class Path(ComPtr, metaclass=_Path_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Shapes.Shape
    default_interface: win32more.Microsoft.UI.Xaml.Shapes.IPath
    _classid_ = 'Microsoft.UI.Xaml.Shapes.Path'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Shapes.Path.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Shapes.IPathFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Microsoft.UI.Xaml.Shapes.Path: ...
    @winrt_mixinmethod
    def get_Data(self: win32more.Microsoft.UI.Xaml.Shapes.IPath) -> win32more.Microsoft.UI.Xaml.Media.Geometry: ...
    @winrt_mixinmethod
    def put_Data(self: win32more.Microsoft.UI.Xaml.Shapes.IPath, value: win32more.Microsoft.UI.Xaml.Media.Geometry) -> Void: ...
    @winrt_classmethod
    def get_DataProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IPathStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Data = property(get_Data, put_Data)
    _Path_Meta_.DataProperty = property(get_DataProperty, None)
class _Polygon_Meta_(ComPtr.__class__):
    pass
class Polygon(ComPtr, metaclass=_Polygon_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Shapes.Shape
    default_interface: win32more.Microsoft.UI.Xaml.Shapes.IPolygon
    _classid_ = 'Microsoft.UI.Xaml.Shapes.Polygon'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Shapes.Polygon.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Shapes.Polygon: ...
    @winrt_mixinmethod
    def get_FillRule(self: win32more.Microsoft.UI.Xaml.Shapes.IPolygon) -> win32more.Microsoft.UI.Xaml.Media.FillRule: ...
    @winrt_mixinmethod
    def put_FillRule(self: win32more.Microsoft.UI.Xaml.Shapes.IPolygon, value: win32more.Microsoft.UI.Xaml.Media.FillRule) -> Void: ...
    @winrt_mixinmethod
    def get_Points(self: win32more.Microsoft.UI.Xaml.Shapes.IPolygon) -> win32more.Microsoft.UI.Xaml.Media.PointCollection: ...
    @winrt_mixinmethod
    def put_Points(self: win32more.Microsoft.UI.Xaml.Shapes.IPolygon, value: win32more.Microsoft.UI.Xaml.Media.PointCollection) -> Void: ...
    @winrt_classmethod
    def get_FillRuleProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IPolygonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PointsProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IPolygonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FillRule = property(get_FillRule, put_FillRule)
    Points = property(get_Points, put_Points)
    _Polygon_Meta_.FillRuleProperty = property(get_FillRuleProperty, None)
    _Polygon_Meta_.PointsProperty = property(get_PointsProperty, None)
class _Polyline_Meta_(ComPtr.__class__):
    pass
class Polyline(ComPtr, metaclass=_Polyline_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Shapes.Shape
    default_interface: win32more.Microsoft.UI.Xaml.Shapes.IPolyline
    _classid_ = 'Microsoft.UI.Xaml.Shapes.Polyline'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Shapes.Polyline.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Shapes.Polyline: ...
    @winrt_mixinmethod
    def get_FillRule(self: win32more.Microsoft.UI.Xaml.Shapes.IPolyline) -> win32more.Microsoft.UI.Xaml.Media.FillRule: ...
    @winrt_mixinmethod
    def put_FillRule(self: win32more.Microsoft.UI.Xaml.Shapes.IPolyline, value: win32more.Microsoft.UI.Xaml.Media.FillRule) -> Void: ...
    @winrt_mixinmethod
    def get_Points(self: win32more.Microsoft.UI.Xaml.Shapes.IPolyline) -> win32more.Microsoft.UI.Xaml.Media.PointCollection: ...
    @winrt_mixinmethod
    def put_Points(self: win32more.Microsoft.UI.Xaml.Shapes.IPolyline, value: win32more.Microsoft.UI.Xaml.Media.PointCollection) -> Void: ...
    @winrt_classmethod
    def get_FillRuleProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IPolylineStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PointsProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IPolylineStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FillRule = property(get_FillRule, put_FillRule)
    Points = property(get_Points, put_Points)
    _Polyline_Meta_.FillRuleProperty = property(get_FillRuleProperty, None)
    _Polyline_Meta_.PointsProperty = property(get_PointsProperty, None)
class _Rectangle_Meta_(ComPtr.__class__):
    pass
class Rectangle(ComPtr, metaclass=_Rectangle_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Shapes.Shape
    default_interface: win32more.Microsoft.UI.Xaml.Shapes.IRectangle
    _classid_ = 'Microsoft.UI.Xaml.Shapes.Rectangle'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Shapes.Rectangle.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Shapes.Rectangle: ...
    @winrt_mixinmethod
    def get_RadiusX(self: win32more.Microsoft.UI.Xaml.Shapes.IRectangle) -> Double: ...
    @winrt_mixinmethod
    def put_RadiusX(self: win32more.Microsoft.UI.Xaml.Shapes.IRectangle, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_RadiusY(self: win32more.Microsoft.UI.Xaml.Shapes.IRectangle) -> Double: ...
    @winrt_mixinmethod
    def put_RadiusY(self: win32more.Microsoft.UI.Xaml.Shapes.IRectangle, value: Double) -> Void: ...
    @winrt_classmethod
    def get_RadiusXProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IRectangleStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RadiusYProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IRectangleStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    RadiusX = property(get_RadiusX, put_RadiusX)
    RadiusY = property(get_RadiusY, put_RadiusY)
    _Rectangle_Meta_.RadiusXProperty = property(get_RadiusXProperty, None)
    _Rectangle_Meta_.RadiusYProperty = property(get_RadiusYProperty, None)
class _Shape_Meta_(ComPtr.__class__):
    pass
class Shape(ComPtr, metaclass=_Shape_Meta_):
    extends: win32more.Microsoft.UI.Xaml.FrameworkElement
    default_interface: win32more.Microsoft.UI.Xaml.Shapes.IShape
    _classid_ = 'Microsoft.UI.Xaml.Shapes.Shape'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Shapes.Shape.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Microsoft.UI.Xaml.Shapes.Shape: ...
    @winrt_mixinmethod
    def get_Fill(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Fill(self: win32more.Microsoft.UI.Xaml.Shapes.IShape, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_Stroke(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Stroke(self: win32more.Microsoft.UI.Xaml.Shapes.IShape, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_StrokeMiterLimit(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> Double: ...
    @winrt_mixinmethod
    def put_StrokeMiterLimit(self: win32more.Microsoft.UI.Xaml.Shapes.IShape, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_StrokeThickness(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> Double: ...
    @winrt_mixinmethod
    def put_StrokeThickness(self: win32more.Microsoft.UI.Xaml.Shapes.IShape, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_StrokeStartLineCap(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> win32more.Microsoft.UI.Xaml.Media.PenLineCap: ...
    @winrt_mixinmethod
    def put_StrokeStartLineCap(self: win32more.Microsoft.UI.Xaml.Shapes.IShape, value: win32more.Microsoft.UI.Xaml.Media.PenLineCap) -> Void: ...
    @winrt_mixinmethod
    def get_StrokeEndLineCap(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> win32more.Microsoft.UI.Xaml.Media.PenLineCap: ...
    @winrt_mixinmethod
    def put_StrokeEndLineCap(self: win32more.Microsoft.UI.Xaml.Shapes.IShape, value: win32more.Microsoft.UI.Xaml.Media.PenLineCap) -> Void: ...
    @winrt_mixinmethod
    def get_StrokeLineJoin(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> win32more.Microsoft.UI.Xaml.Media.PenLineJoin: ...
    @winrt_mixinmethod
    def put_StrokeLineJoin(self: win32more.Microsoft.UI.Xaml.Shapes.IShape, value: win32more.Microsoft.UI.Xaml.Media.PenLineJoin) -> Void: ...
    @winrt_mixinmethod
    def get_StrokeDashOffset(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> Double: ...
    @winrt_mixinmethod
    def put_StrokeDashOffset(self: win32more.Microsoft.UI.Xaml.Shapes.IShape, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_StrokeDashCap(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> win32more.Microsoft.UI.Xaml.Media.PenLineCap: ...
    @winrt_mixinmethod
    def put_StrokeDashCap(self: win32more.Microsoft.UI.Xaml.Shapes.IShape, value: win32more.Microsoft.UI.Xaml.Media.PenLineCap) -> Void: ...
    @winrt_mixinmethod
    def get_StrokeDashArray(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> win32more.Microsoft.UI.Xaml.Media.DoubleCollection: ...
    @winrt_mixinmethod
    def put_StrokeDashArray(self: win32more.Microsoft.UI.Xaml.Shapes.IShape, value: win32more.Microsoft.UI.Xaml.Media.DoubleCollection) -> Void: ...
    @winrt_mixinmethod
    def get_Stretch(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> win32more.Microsoft.UI.Xaml.Media.Stretch: ...
    @winrt_mixinmethod
    def put_Stretch(self: win32more.Microsoft.UI.Xaml.Shapes.IShape, value: win32more.Microsoft.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_mixinmethod
    def get_GeometryTransform(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> win32more.Microsoft.UI.Xaml.Media.Transform: ...
    @winrt_mixinmethod
    def GetAlphaMask(self: win32more.Microsoft.UI.Xaml.Shapes.IShape) -> win32more.Microsoft.UI.Composition.CompositionBrush: ...
    @winrt_classmethod
    def get_FillProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StrokeProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StrokeMiterLimitProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StrokeThicknessProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StrokeStartLineCapProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StrokeEndLineCapProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StrokeLineJoinProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StrokeDashOffsetProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StrokeDashCapProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StrokeDashArrayProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StretchProperty(cls: win32more.Microsoft.UI.Xaml.Shapes.IShapeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Fill = property(get_Fill, put_Fill)
    GeometryTransform = property(get_GeometryTransform, None)
    Stretch = property(get_Stretch, put_Stretch)
    Stroke = property(get_Stroke, put_Stroke)
    StrokeDashArray = property(get_StrokeDashArray, put_StrokeDashArray)
    StrokeDashCap = property(get_StrokeDashCap, put_StrokeDashCap)
    StrokeDashOffset = property(get_StrokeDashOffset, put_StrokeDashOffset)
    StrokeEndLineCap = property(get_StrokeEndLineCap, put_StrokeEndLineCap)
    StrokeLineJoin = property(get_StrokeLineJoin, put_StrokeLineJoin)
    StrokeMiterLimit = property(get_StrokeMiterLimit, put_StrokeMiterLimit)
    StrokeStartLineCap = property(get_StrokeStartLineCap, put_StrokeStartLineCap)
    StrokeThickness = property(get_StrokeThickness, put_StrokeThickness)
    _Shape_Meta_.FillProperty = property(get_FillProperty, None)
    _Shape_Meta_.StretchProperty = property(get_StretchProperty, None)
    _Shape_Meta_.StrokeDashArrayProperty = property(get_StrokeDashArrayProperty, None)
    _Shape_Meta_.StrokeDashCapProperty = property(get_StrokeDashCapProperty, None)
    _Shape_Meta_.StrokeDashOffsetProperty = property(get_StrokeDashOffsetProperty, None)
    _Shape_Meta_.StrokeEndLineCapProperty = property(get_StrokeEndLineCapProperty, None)
    _Shape_Meta_.StrokeLineJoinProperty = property(get_StrokeLineJoinProperty, None)
    _Shape_Meta_.StrokeMiterLimitProperty = property(get_StrokeMiterLimitProperty, None)
    _Shape_Meta_.StrokeProperty = property(get_StrokeProperty, None)
    _Shape_Meta_.StrokeStartLineCapProperty = property(get_StrokeStartLineCapProperty, None)
    _Shape_Meta_.StrokeThicknessProperty = property(get_StrokeThicknessProperty, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Security
import win32more.Windows.Win32.System.Mailslots
@winfunctype('KERNEL32.dll')
def CreateMailslotA(lpName: win32more.Windows.Win32.Foundation.PSTR, nMaxMessageSize: UInt32, lReadTimeout: UInt32, lpSecurityAttributes: POINTER(win32more.Windows.Win32.Security.SECURITY_ATTRIBUTES)) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('KERNEL32.dll')
def CreateMailslotW(lpName: win32more.Windows.Win32.Foundation.PWSTR, nMaxMessageSize: UInt32, lReadTimeout: UInt32, lpSecurityAttributes: POINTER(win32more.Windows.Win32.Security.SECURITY_ATTRIBUTES)) -> win32more.Windows.Win32.Foundation.HANDLE: ...
CreateMailslot = UnicodeAlias('CreateMailslotW')
@winfunctype('KERNEL32.dll')
def GetMailslotInfo(hMailslot: win32more.Windows.Win32.Foundation.HANDLE, lpMaxMessageSize: POINTER(UInt32), lpNextSize: POINTER(UInt32), lpMessageCount: POINTER(UInt32), lpReadTimeout: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetMailslotInfo(hMailslot: win32more.Windows.Win32.Foundation.HANDLE, lReadTimeout: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.System.Implementation.FileExplorer
import win32more.Windows.Web.Http
import win32more.Windows.Win32.System.WinRT
class ISysStorageProviderEventReceivedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Implementation.FileExplorer.ISysStorageProviderEventReceivedEventArgs'
    _iid_ = Guid('{e132d1b9-7b9d-5820-9728-4262b5289142}')
    @winrt_commethod(6)
    def get_Json(self) -> WinRT_String: ...
    Json = property(get_Json, None)
class ISysStorageProviderEventReceivedEventArgsFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Implementation.FileExplorer.ISysStorageProviderEventReceivedEventArgsFactory'
    _iid_ = Guid('{de1a780e-e975-5f68-bcc6-fb46281c6a61}')
    @winrt_commethod(6)
    def CreateInstance(self, json: WinRT_String) -> win32more.Windows.System.Implementation.FileExplorer.SysStorageProviderEventReceivedEventArgs: ...
class ISysStorageProviderEventSource(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Implementation.FileExplorer.ISysStorageProviderEventSource'
    _iid_ = Guid('{1f36c476-9546-536a-8381-2f9a2c08cedd}')
    @winrt_commethod(6)
    def add_EventReceived(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.System.Implementation.FileExplorer.ISysStorageProviderEventSource, win32more.Windows.System.Implementation.FileExplorer.SysStorageProviderEventReceivedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_EventReceived(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    EventReceived = event()
class ISysStorageProviderHandlerFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Implementation.FileExplorer.ISysStorageProviderHandlerFactory'
    _iid_ = Guid('{ee798431-8213-5e89-a623-14d8c72b8a61}')
    @winrt_commethod(6)
    def GetHttpRequestProvider(self, syncRootId: WinRT_String) -> win32more.Windows.System.Implementation.FileExplorer.ISysStorageProviderHttpRequestProvider: ...
    @winrt_commethod(7)
    def GetEventSource(self, syncRootId: WinRT_String, eventName: WinRT_String) -> win32more.Windows.System.Implementation.FileExplorer.ISysStorageProviderEventSource: ...
class ISysStorageProviderHttpRequestProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Implementation.FileExplorer.ISysStorageProviderHttpRequestProvider'
    _iid_ = Guid('{cb6fefb6-e76a-5c25-a33e-3e78a6e0e0ce}')
    @winrt_commethod(6)
    def SendRequestAsync(self, request: win32more.Windows.Web.Http.HttpRequestMessage) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Web.Http.HttpResponseMessage]: ...
class SysStorageProviderEventReceivedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Implementation.FileExplorer.ISysStorageProviderEventReceivedEventArgs
    _classid_ = 'Windows.System.Implementation.FileExplorer.SysStorageProviderEventReceivedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.System.Implementation.FileExplorer.SysStorageProviderEventReceivedEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.System.Implementation.FileExplorer.ISysStorageProviderEventReceivedEventArgsFactory, json: WinRT_String) -> win32more.Windows.System.Implementation.FileExplorer.SysStorageProviderEventReceivedEventArgs: ...
    @winrt_mixinmethod
    def get_Json(self: win32more.Windows.System.Implementation.FileExplorer.ISysStorageProviderEventReceivedEventArgs) -> WinRT_String: ...
    Json = property(get_Json, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Data.Xml.XmlLite
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Com
@winfunctype('XmlLite.dll')
def CreateXmlReader(riid: POINTER(Guid), ppvObject: POINTER(VoidPtr), pMalloc: win32more.Windows.Win32.System.Com.IMalloc) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('XmlLite.dll')
def CreateXmlReaderInputWithEncodingCodePage(pInputStream: win32more.Windows.Win32.System.Com.IUnknown, pMalloc: win32more.Windows.Win32.System.Com.IMalloc, nEncodingCodePage: UInt32, fEncodingHint: win32more.Windows.Win32.Foundation.BOOL, pwszBaseUri: win32more.Windows.Win32.Foundation.PWSTR, ppInput: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('XmlLite.dll')
def CreateXmlReaderInputWithEncodingName(pInputStream: win32more.Windows.Win32.System.Com.IUnknown, pMalloc: win32more.Windows.Win32.System.Com.IMalloc, pwszEncodingName: win32more.Windows.Win32.Foundation.PWSTR, fEncodingHint: win32more.Windows.Win32.Foundation.BOOL, pwszBaseUri: win32more.Windows.Win32.Foundation.PWSTR, ppInput: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('XmlLite.dll')
def CreateXmlWriter(riid: POINTER(Guid), ppvObject: POINTER(VoidPtr), pMalloc: win32more.Windows.Win32.System.Com.IMalloc) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('XmlLite.dll')
def CreateXmlWriterOutputWithEncodingCodePage(pOutputStream: win32more.Windows.Win32.System.Com.IUnknown, pMalloc: win32more.Windows.Win32.System.Com.IMalloc, nEncodingCodePage: UInt32, ppOutput: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('XmlLite.dll')
def CreateXmlWriterOutputWithEncodingName(pOutputStream: win32more.Windows.Win32.System.Com.IUnknown, pMalloc: win32more.Windows.Win32.System.Com.IMalloc, pwszEncodingName: win32more.Windows.Win32.Foundation.PWSTR, ppOutput: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
DtdProcessing = Int32
DtdProcessing_Prohibit: win32more.Windows.Win32.Data.Xml.XmlLite.DtdProcessing = 0
DtdProcessing_Parse: win32more.Windows.Win32.Data.Xml.XmlLite.DtdProcessing = 1
_DtdProcessing_Last: win32more.Windows.Win32.Data.Xml.XmlLite.DtdProcessing = 1
class IXmlReader(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7279fc81-709d-4095-b63d-69fe4b0d9030}')
    @commethod(3)
    def SetInput(self, pInput: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetProperty(self, nProperty: UInt32, ppValue: POINTER(IntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetProperty(self, nProperty: UInt32, pValue: IntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Read(self, pNodeType: POINTER(win32more.Windows.Win32.Data.Xml.XmlLite.XmlNodeType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetNodeType(self, pNodeType: POINTER(win32more.Windows.Win32.Data.Xml.XmlLite.XmlNodeType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def MoveToFirstAttribute(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def MoveToNextAttribute(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def MoveToAttributeByName(self, pwszLocalName: win32more.Windows.Win32.Foundation.PWSTR, pwszNamespaceUri: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def MoveToElement(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetQualifiedName(self, ppwszQualifiedName: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pcwchQualifiedName: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetNamespaceUri(self, ppwszNamespaceUri: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pcwchNamespaceUri: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetLocalName(self, ppwszLocalName: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pcwchLocalName: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetPrefix(self, ppwszPrefix: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pcwchPrefix: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetValue(self, ppwszValue: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pcwchValue: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def ReadValueChunk(self, pwchBuffer: win32more.Windows.Win32.Foundation.PWSTR, cwchChunkSize: UInt32, pcwchRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetBaseUri(self, ppwszBaseUri: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pcwchBaseUri: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def IsDefault(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(20)
    def IsEmptyElement(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(21)
    def GetLineNumber(self, pnLineNumber: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def GetLinePosition(self, pnLinePosition: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetAttributeCount(self, pnAttributeCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def GetDepth(self, pnDepth: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def IsEOF(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
class IXmlResolver(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7279fc82-709d-4095-b63d-69fe4b0d9030}')
    @commethod(3)
    def ResolveUri(self, pwszBaseUri: win32more.Windows.Win32.Foundation.PWSTR, pwszPublicIdentifier: win32more.Windows.Win32.Foundation.PWSTR, pwszSystemIdentifier: win32more.Windows.Win32.Foundation.PWSTR, ppResolvedInput: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXmlWriter(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7279fc88-709d-4095-b63d-69fe4b0d9030}')
    @commethod(3)
    def SetOutput(self, pOutput: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetProperty(self, nProperty: UInt32, ppValue: POINTER(IntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetProperty(self, nProperty: UInt32, pValue: IntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def WriteAttributes(self, pReader: win32more.Windows.Win32.Data.Xml.XmlLite.IXmlReader, fWriteDefaultAttributes: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def WriteAttributeString(self, pwszPrefix: win32more.Windows.Win32.Foundation.PWSTR, pwszLocalName: win32more.Windows.Win32.Foundation.PWSTR, pwszNamespaceUri: win32more.Windows.Win32.Foundation.PWSTR, pwszValue: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def WriteCData(self, pwszText: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def WriteCharEntity(self, wch: Char) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def WriteChars(self, pwch: win32more.Windows.Win32.Foundation.PWSTR, cwch: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def WriteComment(self, pwszComment: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def WriteDocType(self, pwszName: win32more.Windows.Win32.Foundation.PWSTR, pwszPublicId: win32more.Windows.Win32.Foundation.PWSTR, pwszSystemId: win32more.Windows.Win32.Foundation.PWSTR, pwszSubset: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def WriteElementString(self, pwszPrefix: win32more.Windows.Win32.Foundation.PWSTR, pwszLocalName: win32more.Windows.Win32.Foundation.PWSTR, pwszNamespaceUri: win32more.Windows.Win32.Foundation.PWSTR, pwszValue: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def WriteEndDocument(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def WriteEndElement(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def WriteEntityRef(self, pwszName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def WriteFullEndElement(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def WriteName(self, pwszName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def WriteNmToken(self, pwszNmToken: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def WriteNode(self, pReader: win32more.Windows.Win32.Data.Xml.XmlLite.IXmlReader, fWriteDefaultAttributes: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def WriteNodeShallow(self, pReader: win32more.Windows.Win32.Data.Xml.XmlLite.IXmlReader, fWriteDefaultAttributes: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def WriteProcessingInstruction(self, pwszName: win32more.Windows.Win32.Foundation.PWSTR, pwszText: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def WriteQualifiedName(self, pwszLocalName: win32more.Windows.Win32.Foundation.PWSTR, pwszNamespaceUri: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def WriteRaw(self, pwszData: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def WriteRawChars(self, pwch: win32more.Windows.Win32.Foundation.PWSTR, cwch: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def WriteStartDocument(self, standalone: win32more.Windows.Win32.Data.Xml.XmlLite.XmlStandalone) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def WriteStartElement(self, pwszPrefix: win32more.Windows.Win32.Foundation.PWSTR, pwszLocalName: win32more.Windows.Win32.Foundation.PWSTR, pwszNamespaceUri: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def WriteString(self, pwszText: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def WriteSurrogateCharEntity(self, wchLow: Char, wchHigh: Char) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def WriteWhitespace(self, pwszWhitespace: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def Flush(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXmlWriterLite(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{862494c6-1310-4aad-b3cd-2dbeebf670d3}')
    @commethod(3)
    def SetOutput(self, pOutput: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetProperty(self, nProperty: UInt32, ppValue: POINTER(IntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetProperty(self, nProperty: UInt32, pValue: IntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def WriteAttributes(self, pReader: win32more.Windows.Win32.Data.Xml.XmlLite.IXmlReader, fWriteDefaultAttributes: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def WriteAttributeString(self, pwszQName: win32more.Windows.Win32.Foundation.PWSTR, cwszQName: UInt32, pwszValue: win32more.Windows.Win32.Foundation.PWSTR, cwszValue: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def WriteCData(self, pwszText: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def WriteCharEntity(self, wch: Char) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def WriteChars(self, pwch: win32more.Windows.Win32.Foundation.PWSTR, cwch: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def WriteComment(self, pwszComment: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def WriteDocType(self, pwszName: win32more.Windows.Win32.Foundation.PWSTR, pwszPublicId: win32more.Windows.Win32.Foundation.PWSTR, pwszSystemId: win32more.Windows.Win32.Foundation.PWSTR, pwszSubset: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def WriteElementString(self, pwszQName: win32more.Windows.Win32.Foundation.PWSTR, cwszQName: UInt32, pwszValue: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def WriteEndDocument(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def WriteEndElement(self, pwszQName: win32more.Windows.Win32.Foundation.PWSTR, cwszQName: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def WriteEntityRef(self, pwszName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def WriteFullEndElement(self, pwszQName: win32more.Windows.Win32.Foundation.PWSTR, cwszQName: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def WriteName(self, pwszName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def WriteNmToken(self, pwszNmToken: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def WriteNode(self, pReader: win32more.Windows.Win32.Data.Xml.XmlLite.IXmlReader, fWriteDefaultAttributes: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def WriteNodeShallow(self, pReader: win32more.Windows.Win32.Data.Xml.XmlLite.IXmlReader, fWriteDefaultAttributes: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def WriteProcessingInstruction(self, pwszName: win32more.Windows.Win32.Foundation.PWSTR, pwszText: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def WriteRaw(self, pwszData: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def WriteRawChars(self, pwch: win32more.Windows.Win32.Foundation.PWSTR, cwch: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def WriteStartDocument(self, standalone: win32more.Windows.Win32.Data.Xml.XmlLite.XmlStandalone) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def WriteStartElement(self, pwszQName: win32more.Windows.Win32.Foundation.PWSTR, cwszQName: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def WriteString(self, pwszText: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def WriteSurrogateCharEntity(self, wchLow: Char, wchHigh: Char) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def WriteWhitespace(self, pwszWhitespace: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def Flush(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
XmlConformanceLevel = Int32
XmlConformanceLevel_Auto: win32more.Windows.Win32.Data.Xml.XmlLite.XmlConformanceLevel = 0
XmlConformanceLevel_Fragment: win32more.Windows.Win32.Data.Xml.XmlLite.XmlConformanceLevel = 1
XmlConformanceLevel_Document: win32more.Windows.Win32.Data.Xml.XmlLite.XmlConformanceLevel = 2
_XmlConformanceLevel_Last: win32more.Windows.Win32.Data.Xml.XmlLite.XmlConformanceLevel = 2
XmlError = Int32
MX_E_MX: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894464
MX_E_INPUTEND: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894463
MX_E_ENCODING: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894462
MX_E_ENCODINGSWITCH: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894461
MX_E_ENCODINGSIGNATURE: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894460
WC_E_WC: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894432
WC_E_WHITESPACE: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894431
WC_E_SEMICOLON: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894430
WC_E_GREATERTHAN: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894429
WC_E_QUOTE: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894428
WC_E_EQUAL: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894427
WC_E_LESSTHAN: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894426
WC_E_HEXDIGIT: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894425
WC_E_DIGIT: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894424
WC_E_LEFTBRACKET: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894423
WC_E_LEFTPAREN: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894422
WC_E_XMLCHARACTER: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894421
WC_E_NAMECHARACTER: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894420
WC_E_SYNTAX: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894419
WC_E_CDSECT: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894418
WC_E_COMMENT: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894417
WC_E_CONDSECT: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894416
WC_E_DECLATTLIST: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894415
WC_E_DECLDOCTYPE: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894414
WC_E_DECLELEMENT: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894413
WC_E_DECLENTITY: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894412
WC_E_DECLNOTATION: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894411
WC_E_NDATA: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894410
WC_E_PUBLIC: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894409
WC_E_SYSTEM: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894408
WC_E_NAME: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894407
WC_E_ROOTELEMENT: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894406
WC_E_ELEMENTMATCH: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894405
WC_E_UNIQUEATTRIBUTE: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894404
WC_E_TEXTXMLDECL: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894403
WC_E_LEADINGXML: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894402
WC_E_TEXTDECL: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894401
WC_E_XMLDECL: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894400
WC_E_ENCNAME: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894399
WC_E_PUBLICID: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894398
WC_E_PESINTERNALSUBSET: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894397
WC_E_PESBETWEENDECLS: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894396
WC_E_NORECURSION: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894395
WC_E_ENTITYCONTENT: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894394
WC_E_UNDECLAREDENTITY: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894393
WC_E_PARSEDENTITY: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894392
WC_E_NOEXTERNALENTITYREF: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894391
WC_E_PI: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894390
WC_E_SYSTEMID: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894389
WC_E_QUESTIONMARK: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894388
WC_E_CDSECTEND: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894387
WC_E_MOREDATA: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894386
WC_E_DTDPROHIBITED: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894385
WC_E_INVALIDXMLSPACE: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894384
NC_E_NC: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894368
NC_E_QNAMECHARACTER: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894367
NC_E_QNAMECOLON: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894366
NC_E_NAMECOLON: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894365
NC_E_DECLAREDPREFIX: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894364
NC_E_UNDECLAREDPREFIX: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894363
NC_E_EMPTYURI: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894362
NC_E_XMLPREFIXRESERVED: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894361
NC_E_XMLNSPREFIXRESERVED: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894360
NC_E_XMLURIRESERVED: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894359
NC_E_XMLNSURIRESERVED: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894358
SC_E_SC: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894336
SC_E_MAXELEMENTDEPTH: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894335
SC_E_MAXENTITYEXPANSION: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894334
WR_E_WR: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894208
WR_E_NONWHITESPACE: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894207
WR_E_NSPREFIXDECLARED: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894206
WR_E_NSPREFIXWITHEMPTYNSURI: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894205
WR_E_DUPLICATEATTRIBUTE: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894204
WR_E_XMLNSPREFIXDECLARATION: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894203
WR_E_XMLPREFIXDECLARATION: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894202
WR_E_XMLURIDECLARATION: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894201
WR_E_XMLNSURIDECLARATION: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894200
WR_E_NAMESPACEUNDECLARED: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894199
WR_E_INVALIDXMLSPACE: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894198
WR_E_INVALIDACTION: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894197
WR_E_INVALIDSURROGATEPAIR: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072894196
XML_E_INVALID_DECIMAL: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072898019
XML_E_INVALID_HEXIDECIMAL: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072898018
XML_E_INVALID_UNICODE: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072898017
XML_E_INVALIDENCODING: win32more.Windows.Win32.Data.Xml.XmlLite.XmlError = -1072897938
XmlNodeType = Int32
XmlNodeType_None: win32more.Windows.Win32.Data.Xml.XmlLite.XmlNodeType = 0
XmlNodeType_Element: win32more.Windows.Win32.Data.Xml.XmlLite.XmlNodeType = 1
XmlNodeType_Attribute: win32more.Windows.Win32.Data.Xml.XmlLite.XmlNodeType = 2
XmlNodeType_Text: win32more.Windows.Win32.Data.Xml.XmlLite.XmlNodeType = 3
XmlNodeType_CDATA: win32more.Windows.Win32.Data.Xml.XmlLite.XmlNodeType = 4
XmlNodeType_ProcessingInstruction: win32more.Windows.Win32.Data.Xml.XmlLite.XmlNodeType = 7
XmlNodeType_Comment: win32more.Windows.Win32.Data.Xml.XmlLite.XmlNodeType = 8
XmlNodeType_DocumentType: win32more.Windows.Win32.Data.Xml.XmlLite.XmlNodeType = 10
XmlNodeType_Whitespace: win32more.Windows.Win32.Data.Xml.XmlLite.XmlNodeType = 13
XmlNodeType_EndElement: win32more.Windows.Win32.Data.Xml.XmlLite.XmlNodeType = 15
XmlNodeType_XmlDeclaration: win32more.Windows.Win32.Data.Xml.XmlLite.XmlNodeType = 17
_XmlNodeType_Last: win32more.Windows.Win32.Data.Xml.XmlLite.XmlNodeType = 17
XmlReadState = Int32
XmlReadState_Initial: win32more.Windows.Win32.Data.Xml.XmlLite.XmlReadState = 0
XmlReadState_Interactive: win32more.Windows.Win32.Data.Xml.XmlLite.XmlReadState = 1
XmlReadState_Error: win32more.Windows.Win32.Data.Xml.XmlLite.XmlReadState = 2
XmlReadState_EndOfFile: win32more.Windows.Win32.Data.Xml.XmlLite.XmlReadState = 3
XmlReadState_Closed: win32more.Windows.Win32.Data.Xml.XmlLite.XmlReadState = 4
XmlReaderProperty = Int32
XmlReaderProperty_MultiLanguage: win32more.Windows.Win32.Data.Xml.XmlLite.XmlReaderProperty = 0
XmlReaderProperty_ConformanceLevel: win32more.Windows.Win32.Data.Xml.XmlLite.XmlReaderProperty = 1
XmlReaderProperty_RandomAccess: win32more.Windows.Win32.Data.Xml.XmlLite.XmlReaderProperty = 2
XmlReaderProperty_XmlResolver: win32more.Windows.Win32.Data.Xml.XmlLite.XmlReaderProperty = 3
XmlReaderProperty_DtdProcessing: win32more.Windows.Win32.Data.Xml.XmlLite.XmlReaderProperty = 4
XmlReaderProperty_ReadState: win32more.Windows.Win32.Data.Xml.XmlLite.XmlReaderProperty = 5
XmlReaderProperty_MaxElementDepth: win32more.Windows.Win32.Data.Xml.XmlLite.XmlReaderProperty = 6
XmlReaderProperty_MaxEntityExpansion: win32more.Windows.Win32.Data.Xml.XmlLite.XmlReaderProperty = 7
_XmlReaderProperty_Last: win32more.Windows.Win32.Data.Xml.XmlLite.XmlReaderProperty = 7
XmlStandalone = Int32
XmlStandalone_Omit: win32more.Windows.Win32.Data.Xml.XmlLite.XmlStandalone = 0
XmlStandalone_Yes: win32more.Windows.Win32.Data.Xml.XmlLite.XmlStandalone = 1
XmlStandalone_No: win32more.Windows.Win32.Data.Xml.XmlLite.XmlStandalone = 2
_XmlStandalone_Last: win32more.Windows.Win32.Data.Xml.XmlLite.XmlStandalone = 2
XmlWriterProperty = Int32
XmlWriterProperty_MultiLanguage: win32more.Windows.Win32.Data.Xml.XmlLite.XmlWriterProperty = 0
XmlWriterProperty_Indent: win32more.Windows.Win32.Data.Xml.XmlLite.XmlWriterProperty = 1
XmlWriterProperty_ByteOrderMark: win32more.Windows.Win32.Data.Xml.XmlLite.XmlWriterProperty = 2
XmlWriterProperty_OmitXmlDeclaration: win32more.Windows.Win32.Data.Xml.XmlLite.XmlWriterProperty = 3
XmlWriterProperty_ConformanceLevel: win32more.Windows.Win32.Data.Xml.XmlLite.XmlWriterProperty = 4
XmlWriterProperty_CompactEmptyElement: win32more.Windows.Win32.Data.Xml.XmlLite.XmlWriterProperty = 5
_XmlWriterProperty_Last: win32more.Windows.Win32.Data.Xml.XmlLite.XmlWriterProperty = 5


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Management.Policies
import win32more.Windows.Storage.Streams
import win32more.Windows.System
import win32more.Windows.Win32.System.WinRT
class INamedPolicyData(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Management.Policies.INamedPolicyData'
    _iid_ = Guid('{38dcb198-95ac-4077-a643-8078cae26400}')
    @winrt_commethod(6)
    def get_Area(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_Kind(self) -> win32more.Windows.Management.Policies.NamedPolicyKind: ...
    @winrt_commethod(9)
    def get_IsManaged(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_IsUserPolicy(self) -> Boolean: ...
    @winrt_commethod(11)
    def get_User(self) -> win32more.Windows.System.User: ...
    @winrt_commethod(12)
    def GetBoolean(self) -> Boolean: ...
    @winrt_commethod(13)
    def GetBinary(self) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_commethod(14)
    def GetInt32(self) -> Int32: ...
    @winrt_commethod(15)
    def GetInt64(self) -> Int64: ...
    @winrt_commethod(16)
    def GetString(self) -> WinRT_String: ...
    @winrt_commethod(17)
    def add_Changed(self, changedHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Management.Policies.NamedPolicyData, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(18)
    def remove_Changed(self, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Area = property(get_Area, None)
    IsManaged = property(get_IsManaged, None)
    IsUserPolicy = property(get_IsUserPolicy, None)
    Kind = property(get_Kind, None)
    Name = property(get_Name, None)
    User = property(get_User, None)
    Changed = event()
class INamedPolicyStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Management.Policies.INamedPolicyStatics'
    _iid_ = Guid('{7f793be7-76c4-4058-8cad-67662cd05f0d}')
    @winrt_commethod(6)
    def GetPolicyFromPath(self, area: WinRT_String, name: WinRT_String) -> win32more.Windows.Management.Policies.NamedPolicyData: ...
    @winrt_commethod(7)
    def GetPolicyFromPathForUser(self, user: win32more.Windows.System.User, area: WinRT_String, name: WinRT_String) -> win32more.Windows.Management.Policies.NamedPolicyData: ...
class NamedPolicy(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Management.Policies.NamedPolicy'
    @winrt_classmethod
    def GetPolicyFromPath(cls: win32more.Windows.Management.Policies.INamedPolicyStatics, area: WinRT_String, name: WinRT_String) -> win32more.Windows.Management.Policies.NamedPolicyData: ...
    @winrt_classmethod
    def GetPolicyFromPathForUser(cls: win32more.Windows.Management.Policies.INamedPolicyStatics, user: win32more.Windows.System.User, area: WinRT_String, name: WinRT_String) -> win32more.Windows.Management.Policies.NamedPolicyData: ...
class NamedPolicyData(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Management.Policies.INamedPolicyData
    _classid_ = 'Windows.Management.Policies.NamedPolicyData'
    @winrt_mixinmethod
    def get_Area(self: win32more.Windows.Management.Policies.INamedPolicyData) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Name(self: win32more.Windows.Management.Policies.INamedPolicyData) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Kind(self: win32more.Windows.Management.Policies.INamedPolicyData) -> win32more.Windows.Management.Policies.NamedPolicyKind: ...
    @winrt_mixinmethod
    def get_IsManaged(self: win32more.Windows.Management.Policies.INamedPolicyData) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsUserPolicy(self: win32more.Windows.Management.Policies.INamedPolicyData) -> Boolean: ...
    @winrt_mixinmethod
    def get_User(self: win32more.Windows.Management.Policies.INamedPolicyData) -> win32more.Windows.System.User: ...
    @winrt_mixinmethod
    def GetBoolean(self: win32more.Windows.Management.Policies.INamedPolicyData) -> Boolean: ...
    @winrt_mixinmethod
    def GetBinary(self: win32more.Windows.Management.Policies.INamedPolicyData) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_mixinmethod
    def GetInt32(self: win32more.Windows.Management.Policies.INamedPolicyData) -> Int32: ...
    @winrt_mixinmethod
    def GetInt64(self: win32more.Windows.Management.Policies.INamedPolicyData) -> Int64: ...
    @winrt_mixinmethod
    def GetString(self: win32more.Windows.Management.Policies.INamedPolicyData) -> WinRT_String: ...
    @winrt_mixinmethod
    def add_Changed(self: win32more.Windows.Management.Policies.INamedPolicyData, changedHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Management.Policies.NamedPolicyData, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Changed(self: win32more.Windows.Management.Policies.INamedPolicyData, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Area = property(get_Area, None)
    IsManaged = property(get_IsManaged, None)
    IsUserPolicy = property(get_IsUserPolicy, None)
    Kind = property(get_Kind, None)
    Name = property(get_Name, None)
    User = property(get_User, None)
    Changed = event()
class NamedPolicyKind(Enum, Int32):
    Invalid = 0
    Binary = 1
    Boolean = 2
    Int32 = 3
    Int64 = 4
    String = 5


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager
WCM_API_VERSION_1_0: UInt32 = 1
WCM_API_VERSION: UInt32 = 1
WCM_UNKNOWN_DATAPLAN_STATUS: UInt32 = 4294967295
WCM_MAX_PROFILE_NAME: UInt32 = 256
NET_INTERFACE_FLAG_NONE: UInt32 = 0
NET_INTERFACE_FLAG_CONNECT_IF_NEEDED: UInt32 = 1
@winfunctype('wcmapi.dll')
def WcmQueryProperty(pInterface: POINTER(Guid), strProfileName: win32more.Windows.Win32.Foundation.PWSTR, Property: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_PROPERTY, pReserved: VoidPtr, pdwDataSize: POINTER(UInt32), ppData: POINTER(POINTER(Byte))) -> UInt32: ...
@winfunctype('wcmapi.dll')
def WcmSetProperty(pInterface: POINTER(Guid), strProfileName: win32more.Windows.Win32.Foundation.PWSTR, Property: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_PROPERTY, pReserved: VoidPtr, dwDataSize: UInt32, pbData: POINTER(Byte)) -> UInt32: ...
@winfunctype('wcmapi.dll')
def WcmGetProfileList(pReserved: VoidPtr, ppProfileList: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_PROFILE_INFO_LIST))) -> UInt32: ...
@winfunctype('wcmapi.dll')
def WcmSetProfileList(pProfileList: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_PROFILE_INFO_LIST), dwPosition: UInt32, fIgnoreUnknownProfiles: win32more.Windows.Win32.Foundation.BOOL, pReserved: VoidPtr) -> UInt32: ...
@winfunctype('wcmapi.dll')
def WcmFreeMemory(pMemory: VoidPtr) -> Void: ...
@winfunctype('OnDemandConnRouteHelper.dll')
def OnDemandGetRoutingHint(destinationHostName: win32more.Windows.Win32.Foundation.PWSTR, interfaceIndex: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('OnDemandConnRouteHelper.dll')
def OnDemandRegisterNotification(callback: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.ONDEMAND_NOTIFICATION_CALLBACK, callbackContext: VoidPtr, registrationHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('OnDemandConnRouteHelper.dll')
def OnDemandUnRegisterNotification(registrationHandle: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('OnDemandConnRouteHelper.dll')
def GetInterfaceContextTableForHostName(HostName: win32more.Windows.Win32.Foundation.PWSTR, ProxyName: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32, ConnectionProfileFilterRawData: POINTER(Byte), ConnectionProfileFilterRawDataSize: UInt32, InterfaceContextTable: POINTER(POINTER(win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.NET_INTERFACE_CONTEXT_TABLE))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('OnDemandConnRouteHelper.dll')
def FreeInterfaceContextTable(InterfaceContextTable: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.NET_INTERFACE_CONTEXT_TABLE)) -> Void: ...
class NET_INTERFACE_CONTEXT(Structure):
    InterfaceIndex: UInt32
    ConfigurationName: win32more.Windows.Win32.Foundation.PWSTR
class NET_INTERFACE_CONTEXT_TABLE(Structure):
    InterfaceContextHandle: win32more.Windows.Win32.Foundation.HANDLE
    NumberOfEntries: UInt32
    InterfaceContextArray: POINTER(win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.NET_INTERFACE_CONTEXT)
@winfunctype_pointer
def ONDEMAND_NOTIFICATION_CALLBACK(param0: VoidPtr) -> Void: ...
class WCM_BILLING_CYCLE_INFO(Structure):
    StartDate: win32more.Windows.Win32.Foundation.FILETIME
    Duration: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_TIME_INTERVAL
    Reset: win32more.Windows.Win32.Foundation.BOOL
WCM_CONNECTION_COST = Int32
WCM_CONNECTION_COST_UNKNOWN: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_CONNECTION_COST = 0
WCM_CONNECTION_COST_UNRESTRICTED: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_CONNECTION_COST = 1
WCM_CONNECTION_COST_FIXED: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_CONNECTION_COST = 2
WCM_CONNECTION_COST_VARIABLE: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_CONNECTION_COST = 4
WCM_CONNECTION_COST_OVERDATALIMIT: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_CONNECTION_COST = 65536
WCM_CONNECTION_COST_CONGESTED: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_CONNECTION_COST = 131072
WCM_CONNECTION_COST_ROAMING: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_CONNECTION_COST = 262144
WCM_CONNECTION_COST_APPROACHINGDATALIMIT: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_CONNECTION_COST = 524288
class WCM_CONNECTION_COST_DATA(Structure):
    ConnectionCost: UInt32
    CostSource: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_CONNECTION_COST_SOURCE
WCM_CONNECTION_COST_SOURCE = Int32
WCM_CONNECTION_COST_SOURCE_DEFAULT: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_CONNECTION_COST_SOURCE = 0
WCM_CONNECTION_COST_SOURCE_GP: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_CONNECTION_COST_SOURCE = 1
WCM_CONNECTION_COST_SOURCE_USER: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_CONNECTION_COST_SOURCE = 2
WCM_CONNECTION_COST_SOURCE_OPERATOR: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_CONNECTION_COST_SOURCE = 3
class WCM_DATAPLAN_STATUS(Structure):
    UsageData: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_USAGE_DATA
    DataLimitInMegabytes: UInt32
    InboundBandwidthInKbps: UInt32
    OutboundBandwidthInKbps: UInt32
    BillingCycle: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_BILLING_CYCLE_INFO
    MaxTransferSizeInMegabytes: UInt32
    Reserved: UInt32
WCM_MEDIA_TYPE = Int32
wcm_media_unknown: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_MEDIA_TYPE = 0
wcm_media_ethernet: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_MEDIA_TYPE = 1
wcm_media_wlan: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_MEDIA_TYPE = 2
wcm_media_mbn: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_MEDIA_TYPE = 3
wcm_media_invalid: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_MEDIA_TYPE = 4
wcm_media_max: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_MEDIA_TYPE = 5
class WCM_POLICY_VALUE(Structure):
    fValue: win32more.Windows.Win32.Foundation.BOOL
    fIsGroupPolicy: win32more.Windows.Win32.Foundation.BOOL
class WCM_PROFILE_INFO(Structure):
    strProfileName: Char * 256
    AdapterGUID: Guid
    Media: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_MEDIA_TYPE
class WCM_PROFILE_INFO_LIST(Structure):
    dwNumberOfItems: UInt32
    ProfileInfo: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_PROFILE_INFO * 1
WCM_PROPERTY = Int32
wcm_global_property_domain_policy: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_PROPERTY = 0
wcm_global_property_minimize_policy: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_PROPERTY = 1
wcm_global_property_roaming_policy: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_PROPERTY = 2
wcm_global_property_powermanagement_policy: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_PROPERTY = 3
wcm_intf_property_connection_cost: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_PROPERTY = 4
wcm_intf_property_dataplan_status: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_PROPERTY = 5
wcm_intf_property_hotspot_profile: win32more.Windows.Win32.NetworkManagement.WindowsConnectionManager.WCM_PROPERTY = 6
class WCM_TIME_INTERVAL(Structure):
    wYear: UInt16
    wMonth: UInt16
    wDay: UInt16
    wHour: UInt16
    wMinute: UInt16
    wSecond: UInt16
    wMilliseconds: UInt16
class WCM_USAGE_DATA(Structure):
    UsageInMegabytes: UInt32
    LastSyncTime: win32more.Windows.Win32.Foundation.FILETIME


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Microsoft.UI.Xaml
import win32more.Microsoft.UI.Xaml.Automation
import win32more.Microsoft.UI.Xaml.Automation.Peers
import win32more.Microsoft.UI.Xaml.Automation.Provider
import win32more.Microsoft.UI.Xaml.Automation.Text
import win32more.Windows.Foundation
import win32more.Windows.UI
import win32more.Windows.Win32.System.WinRT
class IAnnotationProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IAnnotationProvider'
    _iid_ = Guid('{546ab18e-986d-5deb-8f2a-2d9303a43006}')
    @winrt_commethod(6)
    def get_AnnotationTypeId(self) -> Int32: ...
    @winrt_commethod(7)
    def get_AnnotationTypeName(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_Author(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_DateTime(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_Target(self) -> win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple: ...
    AnnotationTypeId = property(get_AnnotationTypeId, None)
    AnnotationTypeName = property(get_AnnotationTypeName, None)
    Author = property(get_Author, None)
    DateTime = property(get_DateTime, None)
    Target = property(get_Target, None)
class ICustomNavigationProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ICustomNavigationProvider'
    _iid_ = Guid('{cad51322-faa9-5a2b-90f0-b762c46178b3}')
    @winrt_commethod(6)
    def NavigateCustom(self, direction: win32more.Microsoft.UI.Xaml.Automation.Peers.AutomationNavigationDirection) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
class IDockProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IDockProvider'
    _iid_ = Guid('{9882b971-70ea-5c6d-a818-7a7ab68c6f3b}')
    @winrt_commethod(6)
    def get_DockPosition(self) -> win32more.Microsoft.UI.Xaml.Automation.DockPosition: ...
    @winrt_commethod(7)
    def SetDockPosition(self, dockPosition: win32more.Microsoft.UI.Xaml.Automation.DockPosition) -> Void: ...
    DockPosition = property(get_DockPosition, None)
class IDragProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IDragProvider'
    _iid_ = Guid('{c60bb643-a356-5132-a258-ffba6c7480f2}')
    @winrt_commethod(6)
    def get_IsGrabbed(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_DropEffect(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_DropEffects(self) -> ReceiveArray[WinRT_String]: ...
    @winrt_commethod(9)
    def GetGrabbedItems(self) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple]: ...
    DropEffect = property(get_DropEffect, None)
    DropEffects = property(get_DropEffects, None)
    IsGrabbed = property(get_IsGrabbed, None)
class IDropTargetProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IDropTargetProvider'
    _iid_ = Guid('{9b2a9f3d-bbb1-510d-99e8-0e0ae14a6e3b}')
    @winrt_commethod(6)
    def get_DropEffect(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_DropEffects(self) -> ReceiveArray[WinRT_String]: ...
    DropEffect = property(get_DropEffect, None)
    DropEffects = property(get_DropEffects, None)
class IExpandCollapseProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IExpandCollapseProvider'
    _iid_ = Guid('{6cef349c-b181-5d0b-b297-c3b0166120c3}')
    @winrt_commethod(6)
    def get_ExpandCollapseState(self) -> win32more.Microsoft.UI.Xaml.Automation.ExpandCollapseState: ...
    @winrt_commethod(7)
    def Collapse(self) -> Void: ...
    @winrt_commethod(8)
    def Expand(self) -> Void: ...
    ExpandCollapseState = property(get_ExpandCollapseState, None)
class IGridItemProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IGridItemProvider'
    _iid_ = Guid('{d2557a0e-6909-5170-a680-60728df339b4}')
    @winrt_commethod(6)
    def get_Column(self) -> Int32: ...
    @winrt_commethod(7)
    def get_ColumnSpan(self) -> Int32: ...
    @winrt_commethod(8)
    def get_ContainingGrid(self) -> win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple: ...
    @winrt_commethod(9)
    def get_Row(self) -> Int32: ...
    @winrt_commethod(10)
    def get_RowSpan(self) -> Int32: ...
    Column = property(get_Column, None)
    ColumnSpan = property(get_ColumnSpan, None)
    ContainingGrid = property(get_ContainingGrid, None)
    Row = property(get_Row, None)
    RowSpan = property(get_RowSpan, None)
class IGridProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IGridProvider'
    _iid_ = Guid('{50992d5e-d225-56e9-a25a-78c372e81955}')
    @winrt_commethod(6)
    def get_ColumnCount(self) -> Int32: ...
    @winrt_commethod(7)
    def get_RowCount(self) -> Int32: ...
    @winrt_commethod(8)
    def GetItem(self, row: Int32, column: Int32) -> win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple: ...
    ColumnCount = property(get_ColumnCount, None)
    RowCount = property(get_RowCount, None)
class IIRawElementProviderSimple(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IIRawElementProviderSimple'
    _iid_ = Guid('{f90bc239-ade2-55c9-a838-a3b0579763c5}')
class IInvokeProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IInvokeProvider'
    _iid_ = Guid('{02481105-3378-544d-b4e1-a1b368afbc02}')
    @winrt_commethod(6)
    def Invoke(self) -> Void: ...
class IItemContainerProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IItemContainerProvider'
    _iid_ = Guid('{ad297363-694e-5885-997d-a2d6dff415a7}')
    @winrt_commethod(6)
    def FindItemByProperty(self, startAfter: win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple, automationProperty: win32more.Microsoft.UI.Xaml.Automation.AutomationProperty, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple: ...
class IMultipleViewProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IMultipleViewProvider'
    _iid_ = Guid('{60be5484-3d8f-51fd-beab-423422ee1e03}')
    @winrt_commethod(6)
    def get_CurrentView(self) -> Int32: ...
    @winrt_commethod(7)
    def GetSupportedViews(self) -> ReceiveArray[Int32]: ...
    @winrt_commethod(8)
    def GetViewName(self, viewId: Int32) -> WinRT_String: ...
    @winrt_commethod(9)
    def SetCurrentView(self, viewId: Int32) -> Void: ...
    CurrentView = property(get_CurrentView, None)
class IObjectModelProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IObjectModelProvider'
    _iid_ = Guid('{92953ed0-4bd8-5624-8e3d-78d45fde9cf2}')
    @winrt_commethod(6)
    def GetUnderlyingObjectModel(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
class IRangeValueProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IRangeValueProvider'
    _iid_ = Guid('{729ae414-1e8f-5020-82bb-bb574d145fd8}')
    @winrt_commethod(6)
    def get_IsReadOnly(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_LargeChange(self) -> Double: ...
    @winrt_commethod(8)
    def get_Maximum(self) -> Double: ...
    @winrt_commethod(9)
    def get_Minimum(self) -> Double: ...
    @winrt_commethod(10)
    def get_SmallChange(self) -> Double: ...
    @winrt_commethod(11)
    def get_Value(self) -> Double: ...
    @winrt_commethod(12)
    def SetValue(self, value: Double) -> Void: ...
    IsReadOnly = property(get_IsReadOnly, None)
    LargeChange = property(get_LargeChange, None)
    Maximum = property(get_Maximum, None)
    Minimum = property(get_Minimum, None)
    SmallChange = property(get_SmallChange, None)
    Value = property(get_Value, None)
class IRawElementProviderSimple(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Automation.Provider.IIRawElementProviderSimple
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple'
class IScrollItemProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IScrollItemProvider'
    _iid_ = Guid('{8a6fb8eb-e5f1-58eb-8e72-8b95f236fc47}')
    @winrt_commethod(6)
    def ScrollIntoView(self) -> Void: ...
class IScrollProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IScrollProvider'
    _iid_ = Guid('{7e2e5af3-ff50-5365-bcfe-ef424b2fd590}')
    @winrt_commethod(6)
    def get_HorizontallyScrollable(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_HorizontalScrollPercent(self) -> Double: ...
    @winrt_commethod(8)
    def get_HorizontalViewSize(self) -> Double: ...
    @winrt_commethod(9)
    def get_VerticallyScrollable(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_VerticalScrollPercent(self) -> Double: ...
    @winrt_commethod(11)
    def get_VerticalViewSize(self) -> Double: ...
    @winrt_commethod(12)
    def Scroll(self, horizontalAmount: win32more.Microsoft.UI.Xaml.Automation.ScrollAmount, verticalAmount: win32more.Microsoft.UI.Xaml.Automation.ScrollAmount) -> Void: ...
    @winrt_commethod(13)
    def SetScrollPercent(self, horizontalPercent: Double, verticalPercent: Double) -> Void: ...
    HorizontalScrollPercent = property(get_HorizontalScrollPercent, None)
    HorizontalViewSize = property(get_HorizontalViewSize, None)
    HorizontallyScrollable = property(get_HorizontallyScrollable, None)
    VerticalScrollPercent = property(get_VerticalScrollPercent, None)
    VerticalViewSize = property(get_VerticalViewSize, None)
    VerticallyScrollable = property(get_VerticallyScrollable, None)
class ISelectionItemProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ISelectionItemProvider'
    _iid_ = Guid('{c9dfdd81-d4ac-5d31-be7f-24fab16060e4}')
    @winrt_commethod(6)
    def get_IsSelected(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_SelectionContainer(self) -> win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple: ...
    @winrt_commethod(8)
    def AddToSelection(self) -> Void: ...
    @winrt_commethod(9)
    def RemoveFromSelection(self) -> Void: ...
    @winrt_commethod(10)
    def Select(self) -> Void: ...
    IsSelected = property(get_IsSelected, None)
    SelectionContainer = property(get_SelectionContainer, None)
class ISelectionProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ISelectionProvider'
    _iid_ = Guid('{80d56d4e-0052-541f-9411-9d1778b3bfca}')
    @winrt_commethod(6)
    def get_CanSelectMultiple(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_IsSelectionRequired(self) -> Boolean: ...
    @winrt_commethod(8)
    def GetSelection(self) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple]: ...
    CanSelectMultiple = property(get_CanSelectMultiple, None)
    IsSelectionRequired = property(get_IsSelectionRequired, None)
class ISpreadsheetItemProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ISpreadsheetItemProvider'
    _iid_ = Guid('{51c1ce89-b21f-592c-8768-0accdefd5738}')
    @winrt_commethod(6)
    def get_Formula(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def GetAnnotationObjects(self) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple]: ...
    @winrt_commethod(8)
    def GetAnnotationTypes(self) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Automation.AnnotationType]: ...
    Formula = property(get_Formula, None)
class ISpreadsheetProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ISpreadsheetProvider'
    _iid_ = Guid('{1ff41bac-d9e3-5e48-b5f8-9eab0fb2d9d8}')
    @winrt_commethod(6)
    def GetItemByName(self, name: WinRT_String) -> win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple: ...
class IStylesProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IStylesProvider'
    _iid_ = Guid('{d8895839-0048-54de-9c1f-152de6665e80}')
    @winrt_commethod(6)
    def get_ExtendedProperties(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_FillColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(8)
    def get_FillPatternColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(9)
    def get_FillPatternStyle(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_Shape(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def get_StyleId(self) -> Int32: ...
    @winrt_commethod(12)
    def get_StyleName(self) -> WinRT_String: ...
    ExtendedProperties = property(get_ExtendedProperties, None)
    FillColor = property(get_FillColor, None)
    FillPatternColor = property(get_FillPatternColor, None)
    FillPatternStyle = property(get_FillPatternStyle, None)
    Shape = property(get_Shape, None)
    StyleId = property(get_StyleId, None)
    StyleName = property(get_StyleName, None)
class ISynchronizedInputProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ISynchronizedInputProvider'
    _iid_ = Guid('{c5615613-936d-5289-a190-e82057e0ff5a}')
    @winrt_commethod(6)
    def Cancel(self) -> Void: ...
    @winrt_commethod(7)
    def StartListening(self, inputType: win32more.Microsoft.UI.Xaml.Automation.SynchronizedInputType) -> Void: ...
class ITableItemProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ITableItemProvider'
    _iid_ = Guid('{6ce6f038-54d4-5553-a4ad-03cbcf358197}')
    @winrt_commethod(6)
    def GetColumnHeaderItems(self) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple]: ...
    @winrt_commethod(7)
    def GetRowHeaderItems(self) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple]: ...
class ITableProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ITableProvider'
    _iid_ = Guid('{9aba6724-b22d-5db8-8abb-81f911f18af2}')
    @winrt_commethod(6)
    def get_RowOrColumnMajor(self) -> win32more.Microsoft.UI.Xaml.Automation.RowOrColumnMajor: ...
    @winrt_commethod(7)
    def GetColumnHeaders(self) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple]: ...
    @winrt_commethod(8)
    def GetRowHeaders(self) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple]: ...
    RowOrColumnMajor = property(get_RowOrColumnMajor, None)
class ITextChildProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ITextChildProvider'
    _iid_ = Guid('{7c72e55f-f75d-5522-aeb5-c1f82c32933b}')
    @winrt_commethod(6)
    def get_TextContainer(self) -> win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple: ...
    @winrt_commethod(7)
    def get_TextRange(self) -> win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider: ...
    TextContainer = property(get_TextContainer, None)
    TextRange = property(get_TextRange, None)
class ITextEditProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ITextEditProvider'
    _iid_ = Guid('{7f09bbe8-bea7-5dd3-ba6b-28dbb402fad4}')
    @winrt_commethod(6)
    def GetActiveComposition(self) -> win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider: ...
    @winrt_commethod(7)
    def GetConversionTarget(self) -> win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider: ...
class ITextProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ITextProvider'
    _iid_ = Guid('{37e7dce6-fe7a-56a7-a47a-9462872c67ef}')
    @winrt_commethod(6)
    def get_DocumentRange(self) -> win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider: ...
    @winrt_commethod(7)
    def get_SupportedTextSelection(self) -> win32more.Microsoft.UI.Xaml.Automation.SupportedTextSelection: ...
    @winrt_commethod(8)
    def GetSelection(self) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider]: ...
    @winrt_commethod(9)
    def GetVisibleRanges(self) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider]: ...
    @winrt_commethod(10)
    def RangeFromChild(self, childElement: win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple) -> win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider: ...
    @winrt_commethod(11)
    def RangeFromPoint(self, screenLocation: win32more.Windows.Foundation.Point) -> win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider: ...
    DocumentRange = property(get_DocumentRange, None)
    SupportedTextSelection = property(get_SupportedTextSelection, None)
class ITextProvider2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ITextProvider2'
    _iid_ = Guid('{6844f012-c7e6-5763-ba04-5b6db910cd34}')
    @winrt_commethod(6)
    def RangeFromAnnotation(self, annotationElement: win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple) -> win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider: ...
    @winrt_commethod(7)
    def GetCaretRange(self, isActive: POINTER(Boolean)) -> win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider: ...
class ITextRangeProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider'
    _iid_ = Guid('{84210361-6ce2-5084-bf3b-28afa6e9851f}')
    @winrt_commethod(6)
    def Clone(self) -> win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider: ...
    @winrt_commethod(7)
    def Compare(self, textRangeProvider: win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider) -> Boolean: ...
    @winrt_commethod(8)
    def CompareEndpoints(self, endpoint: win32more.Microsoft.UI.Xaml.Automation.Text.TextPatternRangeEndpoint, textRangeProvider: win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider, targetEndpoint: win32more.Microsoft.UI.Xaml.Automation.Text.TextPatternRangeEndpoint) -> Int32: ...
    @winrt_commethod(9)
    def ExpandToEnclosingUnit(self, unit: win32more.Microsoft.UI.Xaml.Automation.Text.TextUnit) -> Void: ...
    @winrt_commethod(10)
    def FindAttribute(self, attributeId: Int32, value: win32more.Windows.Win32.System.WinRT.IInspectable, backward: Boolean) -> win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider: ...
    @winrt_commethod(11)
    def FindText(self, text: WinRT_String, backward: Boolean, ignoreCase: Boolean) -> win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider: ...
    @winrt_commethod(12)
    def GetAttributeValue(self, attributeId: Int32) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(13)
    def GetBoundingRectangles(self, returnValue: ReceiveArray[Double]) -> Void: ...
    @winrt_commethod(14)
    def GetEnclosingElement(self) -> win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple: ...
    @winrt_commethod(15)
    def GetText(self, maxLength: Int32) -> WinRT_String: ...
    @winrt_commethod(16)
    def Move(self, unit: win32more.Microsoft.UI.Xaml.Automation.Text.TextUnit, count: Int32) -> Int32: ...
    @winrt_commethod(17)
    def MoveEndpointByUnit(self, endpoint: win32more.Microsoft.UI.Xaml.Automation.Text.TextPatternRangeEndpoint, unit: win32more.Microsoft.UI.Xaml.Automation.Text.TextUnit, count: Int32) -> Int32: ...
    @winrt_commethod(18)
    def MoveEndpointByRange(self, endpoint: win32more.Microsoft.UI.Xaml.Automation.Text.TextPatternRangeEndpoint, textRangeProvider: win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider, targetEndpoint: win32more.Microsoft.UI.Xaml.Automation.Text.TextPatternRangeEndpoint) -> Void: ...
    @winrt_commethod(19)
    def Select(self) -> Void: ...
    @winrt_commethod(20)
    def AddToSelection(self) -> Void: ...
    @winrt_commethod(21)
    def RemoveFromSelection(self) -> Void: ...
    @winrt_commethod(22)
    def ScrollIntoView(self, alignToTop: Boolean) -> Void: ...
    @winrt_commethod(23)
    def GetChildren(self) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple]: ...
class ITextRangeProvider2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider2'
    _iid_ = Guid('{34d4a80e-36bb-5362-a53b-490428a8b367}')
    @winrt_commethod(6)
    def ShowContextMenu(self) -> Void: ...
class IToggleProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IToggleProvider'
    _iid_ = Guid('{021080c2-30a9-52ef-bc32-2b79847b6ba7}')
    @winrt_commethod(6)
    def get_ToggleState(self) -> win32more.Microsoft.UI.Xaml.Automation.ToggleState: ...
    @winrt_commethod(7)
    def Toggle(self) -> Void: ...
    ToggleState = property(get_ToggleState, None)
class ITransformProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ITransformProvider'
    _iid_ = Guid('{6fd76988-8f52-5ef2-a826-9c8c4951c911}')
    @winrt_commethod(6)
    def get_CanMove(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_CanResize(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_CanRotate(self) -> Boolean: ...
    @winrt_commethod(9)
    def Move(self, x: Double, y: Double) -> Void: ...
    @winrt_commethod(10)
    def Resize(self, width: Double, height: Double) -> Void: ...
    @winrt_commethod(11)
    def Rotate(self, degrees: Double) -> Void: ...
    CanMove = property(get_CanMove, None)
    CanResize = property(get_CanResize, None)
    CanRotate = property(get_CanRotate, None)
class ITransformProvider2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ITransformProvider2'
    _iid_ = Guid('{7d91d02d-8401-5cf8-bbc4-47391a524215}')
    @winrt_commethod(6)
    def get_CanZoom(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_ZoomLevel(self) -> Double: ...
    @winrt_commethod(8)
    def get_MaxZoom(self) -> Double: ...
    @winrt_commethod(9)
    def get_MinZoom(self) -> Double: ...
    @winrt_commethod(10)
    def Zoom(self, zoom: Double) -> Void: ...
    @winrt_commethod(11)
    def ZoomByUnit(self, zoomUnit: win32more.Microsoft.UI.Xaml.Automation.ZoomUnit) -> Void: ...
    CanZoom = property(get_CanZoom, None)
    MaxZoom = property(get_MaxZoom, None)
    MinZoom = property(get_MinZoom, None)
    ZoomLevel = property(get_ZoomLevel, None)
class IValueProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IValueProvider'
    _iid_ = Guid('{984f11cf-4611-588e-b52e-b96a12322c71}')
    @winrt_commethod(6)
    def get_IsReadOnly(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_Value(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def SetValue(self, value: WinRT_String) -> Void: ...
    IsReadOnly = property(get_IsReadOnly, None)
    Value = property(get_Value, None)
class IVirtualizedItemProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IVirtualizedItemProvider'
    _iid_ = Guid('{098f858a-2e63-5985-ab87-f8ebdb1c5740}')
    @winrt_commethod(6)
    def Realize(self) -> Void: ...
class IWindowProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IWindowProvider'
    _iid_ = Guid('{83f1df99-9ddf-575e-a651-2ee657fd16e0}')
    @winrt_commethod(6)
    def get_IsModal(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_IsTopmost(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_Maximizable(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_Minimizable(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_InteractionState(self) -> win32more.Microsoft.UI.Xaml.Automation.WindowInteractionState: ...
    @winrt_commethod(11)
    def get_VisualState(self) -> win32more.Microsoft.UI.Xaml.Automation.WindowVisualState: ...
    @winrt_commethod(12)
    def Close(self) -> Void: ...
    @winrt_commethod(13)
    def SetVisualState(self, state: win32more.Microsoft.UI.Xaml.Automation.WindowVisualState) -> Void: ...
    @winrt_commethod(14)
    def WaitForInputIdle(self, milliseconds: Int32) -> Boolean: ...
    InteractionState = property(get_InteractionState, None)
    IsModal = property(get_IsModal, None)
    IsTopmost = property(get_IsTopmost, None)
    Maximizable = property(get_Maximizable, None)
    Minimizable = property(get_Minimizable, None)
    VisualState = property(get_VisualState, None)


make_ready(__name__)
